@@ -7,7 +7,7 @@ from datetime import datetime
 from openpyxl import load_workbook
 
 from resources import excel_headers
-from excel2meta_interface.utils import messages
+from excel2meta_interface.utils import messages, excel
 
 
 class Excel2Reference:
@@ -21,6 +21,7 @@ class Excel2Reference:
         self.result = messages.message["ok"]
         self.work_book = None
         self.work_sheet = None
+        self.excel_utils = excel.Excel()
 
         try:
             with open(configuration_file) as config:
@@ -40,36 +41,6 @@ class Excel2Reference:
             print("Configuration file >" + configuration_file + "< not found.")
             self.result = messages.message["main_config_not_found"]
 
-    def read_excel(self, file=None, sheet=None):
-        """
-        read a sheet from a provided excel_file file
-        sets:
-            self.work_book: a reference to the loaded work_book
-            self.work_sheet: a reference to the loaded sheet
-        :param file: The Excel file that contains the sheet
-        :param sheet: The Excel sheet in the file to be loaded
-        :return: result = 2 (one or more parameters not provided (None)), 3 (FileNotFound), 10 (IOError), 0 = ok
-        """
-        result = messages.message["ok"]
-        excel_path = ""
-        if file is None or sheet is None:
-            result = messages.message["internal_error"]
-            result["info"] = "read_excel was called without an Excel file name >%s< and/or without a sheet name >%s<." \
-                             % (file, sheet)
-            return result
-
-        try:
-            excel_path = path.join(self.excel_location, file)
-            self.work_book = load_workbook(excel_path)
-            self.work_sheet = self.work_book[sheet]
-        except FileNotFoundError or IOError as e:
-            result = messages.message["excel_not_found"]
-            result["info"] = "Could not find/read Excel >" + excel_path + "<. Error: " + str(e)
-            print(result["info"])
-            return result
-
-        return result
-
     def create_output_files(self):
         overall_result = messages.message["ok"]
         info_datasets = []
@@ -357,14 +328,7 @@ class Excel2Reference:
         return values
 
     def search_value_in_row_index(self, search_string, row=1):
-        """
-        Thankfully copied from
-        https://stackoverflow.com/questions/50491839/python-openpyxl-find-strings-in-column-and-return-row-number
-        """
-        for cell in self.work_sheet[row]:
-            if cell.value == search_string:
-                return cell.column, row
-        return None, row
+        return self.excel_utils.search_value_in_row_index(work_sheet=self.work_sheet, search_string=search_string, row=row)
 
     def search_value_in_column_index(self, search_string, column, give_column, give_column2=None,
                                      name_column1=None, name_column2=None, give_list=False):
@@ -458,15 +422,15 @@ class Excel2Reference:
 
         return result
 
-    def main(self, excel=None, excel_sheet=None):
+    def main(self, excel_file=None, excel_sheet=None):
         if self.result["code"] != "OK":
             return self.result
         if excel_sheet is not None:
             self.excel_sheet = excel_sheet
-        self.json_directory += basename(excel)
+        self.json_directory += basename(excel_file)
         makedirs(self.json_directory, exist_ok=True)
         print(self.json_directory)
-        result = self.read_excel(excel, self.excel_sheet)
+        result, self.work_book, self.work_sheet = self.excel_utils.read_excel(file=excel_file, sheet=self.excel_sheet)
         if result["code"] != "OK":
             return result
 
@@ -476,7 +440,7 @@ class Excel2Reference:
 
 if __name__ == "__main__":
     excel2ref = Excel2Reference(configuration_file="resources/excel2json_config.json")
-    result = excel2ref.main(excel="tryout.xlsx")
+    result = excel2ref.main(excel_file="tryout.xlsx")
     print("result:", result)
     if result["code"] != "OK":
         exit(1)
