@@ -6,6 +6,7 @@ from inspect import currentframe
 from os import path, makedirs
 
 from excel2meta_interface.utils import messages, helpers
+from excel2meta_interface.excel2json import mapping_source_target_zones
 
 
 class JSON2EDCLineageFiles:
@@ -35,6 +36,10 @@ class JSON2EDCLineageFiles:
         self.get_settings(configuration_file=configuration_file)
         makedirs(self.output_directory, exist_ok=True)
 
+        self.mapping_ref = mapping_source_target_zones.MappingSource2TargetZone(
+            excel_file="mapping_overview_consolidated.xlsx", sheet="Sheet3"
+        )
+
     def process_files(self, excelfile=None):
         module = __name__ + "." + currentframe().f_code.co_name
         if excelfile is not None:
@@ -162,6 +167,7 @@ class JSON2EDCLineageFiles:
         return item
 
     def get_datasource_ref(self, ref):
+        print("get_datasource_ref for >%s<" % ref)
         the_layer = "NO_LAYER"
         the_zone = "NO_ZONE"
         the_datasource = "NONE"
@@ -178,6 +184,8 @@ class JSON2EDCLineageFiles:
                 the_zone = item["zone"]
                 the_prefix = item["prefix"]
 
+        print("For ref >%s<: datasource >%s< prefix >%s<, layer >%s<, zone >%s<." % (ref, the_datasource, the_prefix, the_layer, the_zone))
+
         return the_datasource, the_prefix, the_layer, the_zone
 
     def get_dataset_ref(self, src_or_tgt, dataset_name):
